if [ -f /etc/avahi/avahi-daemon.conf ] && cmp -s /etc/defaults/etc/avahi/avahi-daemon.conf /etc/avahi/avahi-daemon.conf
then
    rm /etc/avahi/avahi-daemon.conf
fi

if [ -f /etc/avahi/avahi-dnsconfd.action ] && cmp -s /etc/defaults/etc/avahi/avahi-dnsconfd.action /etc/avahi/avahi-dnsconfd.action
then
    rm /etc/avahi/avahi-dnsconfd.action
fi

if [ -f /etc/avahi/hosts ] && cmp -s /etc/defaults/etc/avahi/hosts /etc/avahi/hosts
then
    rm /etc/avahi/hosts
fi

if [ -f /etc/avahi/services/sftp-ssh.service ] && cmp -s /etc/defaults/etc/avahi/services/sftp-ssh.service /etc/avahi/services/sftp-ssh.service
then
    rm /etc/avahi/services/sftp-ssh.service
fi

if [ -f /etc/avahi/services/ssh.service ] && cmp -s /etc/defaults/etc/avahi/services/ssh.service /etc/avahi/services/ssh.service
then
    rm /etc/avahi/services/ssh.service
fi

